@@ -1,14 +1,15 @@
 import math
-from cprints.config import (
-    PREFIX, SUFFIX, ColorPrintConfig)
+from .config import ColorPrintData
 
+PREFIX = "\033["
+SUFFIX = "\033[0m"
 
-class BasePrint(ColorPrintConfig):
+class ColorPrint(ColorPrintData):
 
-    def colored(self, text, /, *args, fg=None, bg=None, style=None, suffix=True):
-        """\
+    def color(self, text, /, *args, fg=None, bg=None, style=None, suffix=True):
+        """
         :params text   : 着色文本
-        :params *args  : 着色可变参数
+        :params args   : print可变位置参数
         :params fg     : 前景色(black, red, green, yellow, blue, magenta, cyan, white)
         :params bg     : 背景色(black, red, green, yellow, blue, magenta, cyan, white)
         :params style  : 文本样式(default, highlight, underline, flash, reverse)
@@ -17,44 +18,58 @@ class BasePrint(ColorPrintConfig):
         explain:
 
         from cprints import cp
-        text = cp.colored("Hello World", fg=cp.red, bg=cp.black, style=cp.underline)
+        text = cp.color("Hello World", fg=cp.red, bg=cp.black, style=cp.underline)
         print(text)
         """
-        fg     = self.set_foreground(fg)
-        bg     = self.set_background(bg)
-        style  = self.set_style(style)
+        fg = self.set_color_or_style(fg)
+        bg = self.set_color_or_style(bg)
+        style  = self.set_color_or_style(style)
+        # 字体颜色
+        if isinstance(fg, tuple):
+            fg = fg[0]
+        fg = str(fg["code"][0])
+        # 背景颜色
+        if isinstance(bg, tuple):
+            bg = bg[0]
+        bg = str(bg["code"][1])
+        # 字体样式
+        if not isinstance(style, tuple):
+            style = (style, )
+        style = ";".join(set([str(item["code"][0]) for item in style]))
+        # 拼接
+        data  = ";".join([item for item in (style, fg, bg) if item])
+        if not data:
+            data = str(0)
         suffix = SUFFIX if bool(suffix) else ""
         args   = " ".join([str(i) for i in args])
         if args:
             args = " " + args
-        return f"{PREFIX}{style};{fg};{bg}m{text}{args}{suffix}"
+        return f"{PREFIX}{data}m{text}{args}{suffix}"
+
+    colored = color
+
 
     def cprint(self, text, /, *args, fg=None, bg=None, style=None, suffix=True, **kwargs):
-        """\
-        :params text     : 着色文本
-        :params *args    : 着色可变参数
-        :params fg       : 前景色(black, red, green, yellow, blue, magenta, cyan, white)
-        :params bg       : 背景色(black, red, green, yellow, blue, magenta, cyan, white)
-        :params style    : 文本样式(default, highlight, underline, flash, reverse)
-        :params suffix   : 恢复默认打印方式
-        :params **kwargs : print的关键字参数
+        """
+        :params text   : 着色文本
+        :params args   : print可变位置参数
+        :params fg     : 前景色(black, red, green, yellow, blue, magenta, cyan, white)
+        :params bg     : 背景色(black, red, green, yellow, blue, magenta, cyan, white)
+        :params style  : 文本样式(default, highlight, underline, flash, reverse)
+        :params suffix : 恢复默认打印方式
+        :params kwargs : print内置函数可变关键字参数
 
         explain:
 
         from cprints import cp
         cp.cprint("Hello World", fg=cp.red, bg=cp.black, style=cp.underline)
         """
-        fg     = self.set_foreground(fg)
-        bg     = self.set_background(bg)
-        style  = self.set_style(style)
-        suffix = SUFFIX if bool(suffix) else ""
-        args   = " ".join([str(i) for i in args])
-        if args:
-            args = " " + args
-        print(f"{PREFIX}{style};{fg};{bg}m{text}{args}{suffix}", **kwargs)
+        text = self.color(text, *args, fg=fg, bg=bg, style=style, suffix=suffix)
+        print(text, **kwargs)
+
 
     def progress_bar(self, now: int, total: int, lenght=36, bar=b"\xe2\x94\x81", pad=""):
-        """\
+        """
         :params now    : 当前进度值
         :params total  : 总进度值
         :params lenght : 进度条长度
@@ -73,46 +88,57 @@ class BasePrint(ColorPrintConfig):
         # 百分比
         percent = now / total
         # 进度条总长度
-        total_bar  = len(self.colored(lenght * bar))
+        total_bar  = len(self.color(lenght * bar))
         foreground = self.red if now < total else self.green
         # 进度条
-        progress_bar = self.colored(
+        progress_bar = self.color(
             math.floor(percent * lenght) * bar, fg=foreground)
         # 需要打印的百分比
-        percent = self.colored(f"{percent:.2%}", fg=self.magenta)
-        _num    = self.colored(f"{now}/{total}", fg=self.yellow)
+        percent = self.color(f"{percent:.2%}", fg=self.magenta)
+        _num    = self.color(f"{now}/{total}", fg=self.yellow)
         end     = "\n" if now >= total else ""
-        print(f"\r{percent} {progress_bar:{pad}<{total_bar}} {_num} ", end=end, flush=True)
+        print(f"\r{percent: >16} {progress_bar:{pad}<{total_bar}} {_num} ", end=end, flush=True)
 
 
-class Colored(BasePrint):
+    def color_black(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.black, bg=bg, style=style, suffix=suffix)
 
-    def colored_black(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.black, bg=bg, style=style, suffix=suffix)
+    colored_black = color_black
 
-    def colored_red(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.red, bg=bg, style=style, suffix=suffix)
+    def color_red(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.red, bg=bg, style=style, suffix=suffix)
 
-    def colored_green(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.green, bg=bg, style=style, suffix=suffix)
+    colored_red = color_red
 
-    def colored_yellow(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.yellow, bg=bg, style=style, suffix=suffix)
+    def color_green(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.green, bg=bg, style=style, suffix=suffix)
 
-    def colored_blue(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.blue, bg=bg, style=style, suffix=suffix)
+    colored_green = color_green
 
-    def colored_magenta(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.magenta, bg=bg, style=style, suffix=suffix)
+    def color_yellow(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.yellow, bg=bg, style=style, suffix=suffix)
 
-    def colored_cyan(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.cyan, bg=bg, style=style, suffix=suffix)
+    colored_yellow = color_yellow
 
-    def colored_white(self, text, /, *args, bg=None, style=None, suffix=True):
-        return self.colored(text, *args, fg=self.white, bg=bg, style=style, suffix=suffix)
+    def color_blue(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.blue, bg=bg, style=style, suffix=suffix)
 
+    colored_blue = color_blue
 
-class ColorPrint(Colored):
+    def color_magenta(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.magenta, bg=bg, style=style, suffix=suffix)
+
+    colored_magenta = color_magenta
+
+    def color_cyan(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.cyan, bg=bg, style=style, suffix=suffix)
+
+    colored_cyan = color_cyan
+
+    def color_white(self, text, /, *args, bg=None, style=None, suffix=True):
+        return self.color(text, *args, fg=self.white, bg=bg, style=style, suffix=suffix)
+
+    colored_white = color_white
 
     def print_black(self, text ,/, *args, bg=None, style=None, suffix=True, **kwargs):
         self.cprint(text, *args, fg=self.black, bg=bg, style=style, suffix=suffix, **kwargs)
